@@ -401,7 +401,11 @@ assay_facets: Facets = {
         "Images": FacetConfig(["/ihc/ihc_image."]),
         "Combined Markers": FacetConfig(["csv|ihc marker combined"]),
     },
-    "H&E": {"Images": FacetConfig(["/hande/image_file.svs"], "Stained image file.")},
+    "H&E": {
+        "Images": FacetConfig(
+            ["/hande/image_file.svs", "/hande/image_file."], "Stained image file."
+        )
+    },
     "TCR": {
         "Source": FacetConfig(
             [
